==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Input/sid/translations/sid_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="69"/>
        <source>SID Plugin</source>
        <translation>תוספת SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="71"/>
        <source>SID Files</source>
        <translation>קבצי SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="125"/>
        <source>About SID Audio Plugin</source>
        <translation>אודות תוספת שמע SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="126"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>אודות תוספת שמע SID של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="127"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>תוספת זו מנגנת קבצי מוזיקה של Commodore 64 באמצעות ספריית libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>הגדרות תוספת SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>דיגום נוסף מהיר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>קובץ מסד נתונים HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>שיטת דגימה חוזרת:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>אריכות שיר ברירות מחדל, שניות:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>אפשר מסד נתונים אריכות שיר HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>הדמיה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
</context>
</TS>

==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/sid/translations/sid_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="77"/>
        <source>SID Plugin</source>
        <translation>תוסף SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="79"/>
        <source>SID Files</source>
        <translation>קבצי SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="133"/>
        <source>About SID Audio Plugin</source>
        <translation>אודות תוסף שמע SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="134"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>אודות תוסף שמע SID של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="135"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>תוסף זה מנגן קבצי מוזיקה של Commodore 64 באמצעות ספריית libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>הגדרות תוסף SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>דיגום נוסף מהיר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>שיעור דגימה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>קובץ מסד נתונים HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>שיטת דגימה חוזרת:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>אריכות שיר ברירות מחדל, שניות:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>אפשר מסד נתונים אריכות שיר HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>הדמיה:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 הרץ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 הרץ</translation>
    </message>
</context>
</TS>
